@@ -2,8 +2,9 @@ package HTML::TurboForm::Element;
 
 use warnings;
 use strict;
+use Scalar::MoreUtils qw(empty);
 use base qw/ Class::Accessor /;
-__PACKAGE__->mk_accessors( qw/ params submit wrapper errorclass pure default dbsearchfield dbdata dbop dbid dblabel ignore_dbix type id name label text value request options optionsnum class left_class limit right_class row_class attributes table submit columns / );
+__PACKAGE__->mk_accessors( qw/ params submit wrapper errorclass pure default dbsearchfield dbdata optionstext dbop dbid dblabel ignore_dbix type id name label text value request options optionsnum class left_class limit right_class row_class attributes table submit columns / );
 
 sub new{
     my ($class, $request) = @_;
@@ -50,7 +51,6 @@ sub init{
 
 sub add_options{
    my ($self, $opt) = @_;
-
    $self->{options} = $opt;
 }
 
@@ -213,12 +213,11 @@ sub get_label{
 
 sub get_value{
     my ($self) = @_;
-    my $result='';
-    $result=$self->{request}->{$self->name} if exists($self->{request}->{$self->name});
+    my $result='';    
+    $result=$self->{request}->{$self->name} if (!empty($self->{request}->{$self->name}));    
     return $result;
 }
 
-
 1;
 
 
